@@ -7,7 +7,7 @@ bindings : KeyBindings
     A container for key bindings.
 this_files_path : str
     The Path to this file.
-    """
+"""
 import os
 import sys
 from typing import Dict, Iterable, List, Optional, Tuple
@@ -41,6 +41,7 @@ from pygments.token import (
 )
 from rich.table import Table
 from sqlalchemy import create_engine, inspect
+from sqlalchemy.exc import ResourceClosedError
 
 import pyprql.lang.prql as prql
 from pyprql import __version__ as pyprql_version
@@ -193,10 +194,21 @@ class PRQLCompleter(Completer):
             "select": self.column_names,
             " ": self.column_names,
             "sort": self.column_names,
+            "sum": self.column_names,
+            "avg": self.column_names,
+            "min": self.column_names,
+            "max": self.column_names,
+            "count": self.column_names,
             "filter": self.column_names,
-            "show": ["tables", "columns", "connection"],
-            "exit": None,
+            "exit": [""],
         }
+        matches_that_need_prev_word = {
+            "show": ["tables", "columns", "connection"],
+            "side:": ["left", "inner", "right", "outer"],
+            "order:": ["asc", "desc"],
+            "by:": self.column_names,
+        }
+        # print(word_before_cursor)
         for op in completion_operators:
             possible_matches[op] = self.column_names
 
@@ -221,7 +233,11 @@ class PRQLCompleter(Completer):
             else:
                 for m in selection:
                     yield Completion(m, start_position=-len(word_before_cursor))
-
+        elif word_before_cursor in matches_that_need_prev_word:
+            selection = matches_that_need_prev_word[word_before_cursor]
+            #            selection = [f"{x}" for x in selection]
+            for m in selection:
+                yield Completion(m, start_position=0)
         # If its an operator
         elif (
             len(word_before_cursor) >= 1
@@ -333,11 +349,14 @@ class CLI:
             for column in columns:
                 table.add_column(column, justify="left")
 
-            for _row in rs:
-                row = list(_row)
-                table.add_row(*[str(x) for x in row])
-
-            rich.print(table)
+            try:
+                for _row in rs:
+                    row = list(_row)
+                    table.add_row(*[str(x) for x in row])
+            except ResourceClosedError:
+                rich.print("")
+            else:
+                rich.print(table)
 
     def highlight_prql(self, text: str) -> str:
         """Provide highlighting for PRQL inputs.
@@ -396,7 +415,7 @@ class CLI:
             sys.exit(0)
         elif user_input == "examples":
             # That would likely increase maintainability
-            rich.print(prql.read_file("examples.txt", this_files_path))
+            rich.print(prql.read_file("../assets/examples.txt", this_files_path))
             return
         elif user_input == "?" or user_input == "help":
             rich.print("PyPRQL version: {}".format(pyprql_version))
@@ -443,10 +462,9 @@ class CLI:
 
                 self.has_one_blank = False
                 sql = self.command
-                if "LIMIT" not in sql:
-                    sql += " LIMIT 5"
+                if "SELECT" in sql and "LIMIT" not in sql:
+                    sql += " LIMIT 25"
 
-                print("\t" + self.highlight_sql(sql))
                 self.prompt_text = "SQL> "
                 self.execute_sql(sql)
 
@@ -517,6 +535,7 @@ class CLI:
 
 
 def print_usage() -> None:
+    """Prints the usage information for the CLI."""
     print(prql.read_file("../assets/cli_usage.txt", this_files_path))
 
 
